pub struct PermissionsClient<T> { /* private fields */ }Implementations
Sourceimpl<T> PermissionsClient<T>where
T: Client,
impl<T> PermissionsClient<T>where
T: Client,
Sourceimpl<T> PermissionsClient<T>where
T: Client,
impl<T> PermissionsClient<T>where
T: Client,
Sourcepub async fn get(&self, params: GetParams) -> Result<GetOutput, T::Error>
pub async fn get(&self, params: GetParams) -> Result<GetOutput, T::Error>
Retrieve effective permissions of given user/token.
Each user/token is allowed to dump their own permissions (or that of owned tokens). A user can dump the permissions of another user or their tokens if they have ‘Sys.Audit’ permission on /access.