pub struct GetOutput {
pub api: Option<Api>,
pub data: Option<String>,
pub digest: Option<DigestStr>,
pub disable: Option<bool>,
pub nodes: Option<String>,
pub plugin: String,
pub ty: Type,
pub validation_delay: Option<ValidationDelayInt>,
pub additional_properties: HashMap<String, Value>,
}Fields
api: Option<Api>API plugin name
data: Option<String>DNS plugin data. (base64 encoded)
digest: Option<DigestStr>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
disable: Option<bool>Flag to disable the config.
nodes: Option<String>List of cluster node names.
plugin: StringUnique identifier for ACME plugin instance.
ty: TypeACME challenge type.
validation_delay: Option<ValidationDelayInt>Extra delay in seconds to wait before requesting validation. Allows to cope with a long TTL of DNS records.
additional_properties: HashMap<String, Value>Implementations