pub enum Affinity {
Negative,
Positive,
}Expand description
Describes whether the HA resources are supposed to be kept on the same node (‘positive’), or are supposed to be kept on separate nodes (‘negative’).
Variants