pub struct PostParams {
pub affinity: Option<Affinity>,
pub comment: Option<CommentStr>,
pub disable: Option<bool>,
pub nodes: Option<String>,
pub resources: String,
pub rule: String,
pub strict: Option<bool>,
pub ty: Type,
pub additional_properties: HashMap<String, Value>,
}Fields
affinity: Option<Affinity>Describes whether the HA resources are supposed to be kept on the same node (‘positive’), or are supposed to be kept on separate nodes (‘negative’).
comment: Option<CommentStr>HA rule description.
disable: Option<bool>Whether the HA rule is disabled.
nodes: Option<String>List of cluster node names with optional priority.
List of cluster node members, where a priority can be given to each node. A resource will run on the available nodes with the highest priority. If there are more nodes in the highest priority class, the resources will get distributed to those nodes. The priorities have a relative meaning only. The higher the number, the higher the priority.
resources: StringList of HA resource IDs. This consists of a list of resource types followed by a resource specific name separated with a colon (example: vm:100,ct:101).
rule: StringHA rule identifier.
strict: Option<bool>Describes whether the node affinity rule is strict or non-strict.
Describes whether the node affinity rule is strict or non-strict.
A non-strict node affinity rule makes resources prefer to be on the defined nodes.
If none of the defined nodes are available, the resource may run on any other node.
A strict node affinity rule makes resources be restricted to the defined nodes. If
none of the defined nodes are available, the resource will be stopped.
ty: TypeHA rule type.
additional_properties: HashMap<String, Value>Implementations