pub struct PostParams {
pub body: Option<String>,
pub comment: Option<String>,
pub disable: Option<bool>,
pub header: Vec<String>,
pub method: Method,
pub name: String,
pub secret: Vec<String>,
pub url: String,
pub additional_properties: HashMap<String, Value>,
}Fields
body: Option<String>HTTP body, base64 encoded
comment: Option<String>Comment
disable: Option<bool>Disable this target
header: Vec<String>HTTP headers to set. These have to be formatted as a property string in the format name=\<name\>,value=\<base64 of value\>
method: MethodHTTP method
name: StringThe name of the endpoint.
secret: Vec<String>Secrets to set. These have to be formatted as a property string in the format name=\<name\>,value=\<base64 of value\>
url: StringServer URL
additional_properties: HashMap<String, Value>Implementations