Module replication

Module replication 

Modules

id

Structs

CommentStr
GetOutputItems
IdStr
PostParams
RateNum
ReplicationClient
ScheduleStr

Enums

RemoveJob
Mark the replication job for removal. The job will remove all local replication snapshots. When set to ‘full’, it also tries to remove replicated volumes on the target. The job then removes itself from the configuration file.
Type
Section type.