pub enum RemoveJob {
Full,
Local,
}Expand description
Mark the replication job for removal. The job will remove all local replication snapshots. When set to ‘full’, it also tries to remove replicated volumes on the target. The job then removes itself from the configuration file.
Variants