pub struct GetOutput {Show 13 fields
pub comment: Option<CommentStr>,
pub digest: Option<DigestStr>,
pub disable: Option<bool>,
pub guest: i64,
pub id: IdStr,
pub jobnum: i64,
pub rate: Option<RateNum>,
pub remove_job: Option<RemoveJob>,
pub schedule: Option<ScheduleStr>,
pub source: Option<String>,
pub target: String,
pub ty: Type,
pub additional_properties: HashMap<String, Value>,
}Fields
comment: Option<CommentStr>Description.
digest: Option<DigestStr>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
disable: Option<bool>Flag to disable/deactivate the entry.
guest: i64Guest ID.
id: IdStrReplication Job ID. The ID is composed of a Guest ID and a job number, separated by a hyphen, i.e. ‘\<GUEST\>-\<JOBNUM\>’.
jobnum: i64Unique, sequential ID assigned to each job.
rate: Option<RateNum>Rate limit in mbps (megabytes per second) as floating point number.
remove_job: Option<RemoveJob>Mark the replication job for removal. The job will remove all local replication snapshots. When set to ‘full’, it also tries to remove replicated volumes on the target. The job then removes itself from the configuration file.
schedule: Option<ScheduleStr>Storage replication schedule. The format is a subset of systemd calendar events.
source: Option<String>For internal use, to detect if the guest was stolen.
target: StringTarget node.
ty: TypeSection type.
additional_properties: HashMap<String, Value>