GetOutputItems

Struct GetOutputItems 

pub struct GetOutputItems {
Show 34 fields pub cgroup_mode: Option<i64>, pub content: Option<String>, pub cpu: Option<CpuNum>, pub disk: Option<u64>, pub diskread: Option<i64>, pub diskwrite: Option<i64>, pub hastate: Option<String>, pub id: String, pub level: Option<String>, pub lock: Option<String>, pub maxcpu: Option<MaxcpuNum>, pub maxdisk: Option<u64>, pub maxmem: Option<i64>, pub mem: Option<u64>, pub memhost: Option<u64>, pub name: Option<String>, pub netin: Option<i64>, pub netout: Option<i64>, pub network: Option<String>, pub network_type: Option<NetworkType>, pub node: Option<String>, pub plugintype: Option<String>, pub pool: Option<String>, pub protocol: Option<String>, pub sdn: Option<String>, pub status: Option<String>, pub storage: Option<String>, pub tags: Option<String>, pub template: Option<bool>, pub ty: Type2, pub uptime: Option<i64>, pub vmid: Option<VmidInt>, pub zone_type: Option<String>, pub additional_properties: HashMap<String, Value>,
}

Fields

cgroup_mode: Option<i64>

The cgroup mode the node operates under (for type ‘node’).

content: Option<String>

Allowed storage content types (for type ‘storage’).

cpu: Option<CpuNum>

CPU utilization (for types ‘node’, ‘qemu’ and ‘lxc’).

disk: Option<u64>

Used disk space in bytes (for type ‘storage’), used root image space for VMs (for types ‘qemu’ and ‘lxc’).

diskread: Option<i64>

The number of bytes the guest read from its block devices since the guest was started. This info is not available for all storage types. (for types ‘qemu’ and ‘lxc’)

diskwrite: Option<i64>

The number of bytes the guest wrote to its block devices since the guest was started. This info is not available for all storage types. (for types ‘qemu’ and ‘lxc’)

hastate: Option<String>

HA service status (for HA managed VMs).

id: String

Resource id.

level: Option<String>

Support level (for type ‘node’).

lock: Option<String>

The guest’s current config lock (for types ‘qemu’ and ‘lxc’)

maxcpu: Option<MaxcpuNum>

Number of available CPUs (for types ‘node’, ‘qemu’ and ‘lxc’).

maxdisk: Option<u64>

Storage size in bytes (for type ‘storage’), root image size for VMs (for types ‘qemu’ and ‘lxc’).

maxmem: Option<i64>

Number of available memory in bytes (for types ‘node’, ‘qemu’ and ‘lxc’).

mem: Option<u64>

Used memory in bytes (for types ‘node’, ‘qemu’ and ‘lxc’).

memhost: Option<u64>

Used memory in bytes from the point of view of the host (for types ‘qemu’).

name: Option<String>

Name of the resource.

netin: Option<i64>

The amount of traffic in bytes that was sent to the guest over the network since it was started. (for types ‘qemu’ and ‘lxc’)

netout: Option<i64>

The amount of traffic in bytes that was sent from the guest over the network since it was started. (for types ‘qemu’ and ‘lxc’)

network: Option<String>

The name of a Network entity (for type ‘network’).

network_type: Option<NetworkType>

The type of network resource (for type ‘network’).

node: Option<String>

The cluster node name (for types ‘node’, ‘storage’, ‘qemu’, and ‘lxc’).

plugintype: Option<String>

More specific type, if available.

pool: Option<String>

The pool name (for types ‘pool’, ‘qemu’ and ‘lxc’).

protocol: Option<String>

The protocol of a fabric (for type ‘network’, network-type ‘fabric’).

sdn: Option<String>

The name of an SDN entity (for type ‘sdn’)

status: Option<String>

Resource type dependent status.

storage: Option<String>

The storage identifier (for type ‘storage’).

tags: Option<String>

The guest’s tags (for types ‘qemu’ and ‘lxc’)

template: Option<bool>

Determines if the guest is a template. (for types ‘qemu’ and ‘lxc’)

ty: Type2

Resource type.

uptime: Option<i64>

Uptime of node or virtual guest in seconds (for types ‘node’, ‘qemu’ and ‘lxc’).

vmid: Option<VmidInt>

The numerical vmid (for types ‘qemu’ and ‘lxc’).

zone_type: Option<String>

The type of an SDN zone (for type ‘sdn’).

additional_properties: HashMap<String, Value>

Implementations

Source

impl GetOutputItems

pub fn new(id: String, ty: Type2) -> Self