pub struct PutParams {Show 15 fields
pub asn: Option<AsnInt>,
pub bgp_multipath_as_path_relax: Option<bool>,
pub delete: Option<DeleteStr>,
pub digest: Option<DigestStr>,
pub ebgp: Option<bool>,
pub ebgp_multihop: Option<i64>,
pub fabric: Option<String>,
pub isis_domain: Option<String>,
pub isis_ifaces: Option<String>,
pub isis_net: Option<String>,
pub lock_token: Option<String>,
pub loopback: Option<String>,
pub node: Option<String>,
pub peers: Option<String>,
pub additional_properties: HashMap<String, Value>,
}Fields
asn: Option<AsnInt>autonomous system number
bgp_multipath_as_path_relax: Option<bool>Consider different AS paths of equal length for multipath computation.
delete: Option<DeleteStr>A list of settings you want to delete.
digest: Option<DigestStr>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
ebgp: Option<bool>Enable eBGP (remote-as external).
ebgp_multihop: Option<i64>Set maximum amount of hops for eBGP peers.
fabric: Option<String>SDN fabric to use as underlay for this EVPN controller.
isis_domain: Option<String>Name of the IS-IS domain.
isis_ifaces: Option<String>Comma-separated list of interfaces where IS-IS should be active.
isis_net: Option<String>Network Entity title for this node in the IS-IS network.
lock_token: Option<String>the token for unlocking the global SDN configuration
loopback: Option<String>Name of the loopback/dummy interface that provides the Router-IP.
node: Option<String>The cluster node name.
peers: Option<String>peers address list.
additional_properties: HashMap<String, Value>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PutParams
impl<'de> Deserialize<'de> for PutParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more