pub struct GetOutputItems {Show 16 fields
pub asn: Option<AsnInt>,
pub bgp_multipath_as_relax: Option<bool>,
pub controller: String,
pub digest: Option<String>,
pub ebgp: Option<bool>,
pub ebgp_multihop: Option<i64>,
pub isis_domain: Option<String>,
pub isis_ifaces: Option<String>,
pub isis_net: Option<String>,
pub loopback: Option<String>,
pub node: Option<String>,
pub peers: Option<String>,
pub pending: Option<PendingGetOutputItemsPending>,
pub state: Option<State>,
pub ty: Type,
pub additional_properties: HashMap<String, Value>,
}Fields
asn: Option<AsnInt>The local ASN of the controller. BGP & EVPN only.
bgp_multipath_as_relax: Option<bool>Consider different AS paths of equal length for multipath computation. BGP only.
controller: StringName of the controller.
digest: Option<String>Digest of the controller section.
ebgp: Option<bool>Enable eBGP (remote-as external). BGP only.
ebgp_multihop: Option<i64>Set maximum amount of hops for eBGP peers. Needs ebgp set to 1. BGP only.
isis_domain: Option<String>Name of the IS-IS domain. IS-IS only.
isis_ifaces: Option<String>Comma-separated list of interfaces where IS-IS should be active. IS-IS only.
isis_net: Option<String>Network Entity title for this node in the IS-IS network. IS-IS only.
loopback: Option<String>Name of the loopback/dummy interface that provides the Router-IP. BGP only.
node: Option<String>Node(s) where this controller is active.
peers: Option<String>Comma-separated list of the peers IP addresses.
pending: Option<PendingGetOutputItemsPending>Changes that have not yet been applied to the running configuration.
state: Option<State>State of the SDN configuration object.
ty: TypeType of the controller
additional_properties: HashMap<String, Value>Implementations