pub struct PostParams {Show 15 fields
pub asn: Option<AsnInt>,
pub bgp_multipath_as_path_relax: Option<bool>,
pub controller: String,
pub ebgp: Option<bool>,
pub ebgp_multihop: Option<i64>,
pub fabric: Option<String>,
pub isis_domain: Option<String>,
pub isis_ifaces: Option<String>,
pub isis_net: Option<String>,
pub lock_token: Option<String>,
pub loopback: Option<String>,
pub node: Option<String>,
pub peers: Option<String>,
pub ty: Type,
pub additional_properties: HashMap<String, Value>,
}Fields
asn: Option<AsnInt>autonomous system number
bgp_multipath_as_path_relax: Option<bool>Consider different AS paths of equal length for multipath computation.
controller: StringThe SDN controller object identifier.
ebgp: Option<bool>Enable eBGP (remote-as external).
ebgp_multihop: Option<i64>Set maximum amount of hops for eBGP peers.
fabric: Option<String>SDN fabric to use as underlay for this EVPN controller.
isis_domain: Option<String>Name of the IS-IS domain.
isis_ifaces: Option<String>Comma-separated list of interfaces where IS-IS should be active.
isis_net: Option<String>Network Entity title for this node in the IS-IS network.
lock_token: Option<String>the token for unlocking the global SDN configuration
loopback: Option<String>Name of the loopback/dummy interface that provides the Router-IP.
node: Option<String>The cluster node name.
peers: Option<String>peers address list.
ty: TypePlugin type.
additional_properties: HashMap<String, Value>Implementations