pub struct GetOutputItems {
pub alias: Option<AliasStr>,
pub digest: Option<String>,
pub isolate_ports: Option<bool>,
pub pending: Option<PendingGetOutputItemsPending>,
pub state: Option<State>,
pub tag: Option<TagInt>,
pub ty: Type,
pub vlanaware: Option<bool>,
pub vnet: String,
pub zone: Option<String>,
pub additional_properties: HashMap<String, Value>,
}Fields
alias: Option<AliasStr>Alias name of the VNet.
digest: Option<String>Digest of the VNet section.
isolate_ports: Option<bool>If true, sets the isolated property for all interfaces on the bridge of this VNet.
pending: Option<PendingGetOutputItemsPending>Changes that have not yet been applied to the running configuration.
state: Option<State>State of the SDN configuration object.
tag: Option<TagInt>VLAN Tag (for VLAN or QinQ zones) or VXLAN VNI (for VXLAN or EVPN zones).
ty: TypeType of the VNet.
vlanaware: Option<bool>Allow VLANs to pass through this VNet.
vnet: StringName of the VNet.
zone: Option<String>Name of the zone this VNet belongs to.
additional_properties: HashMap<String, Value>Implementations