pub struct PostParams {Show 13 fields
pub add_storages: Option<bool>,
pub application: Option<Application>,
pub crush_rule: Option<String>,
pub erasure_coding: Option<String>,
pub min_size: Option<MinSizeInt>,
pub name: NameStr,
pub pg_autoscale_mode: Option<PgAutoscaleMode>,
pub pg_num: Option<PgNumInt>,
pub pg_num_min: Option<PgNumMinInt>,
pub size: Option<SizeInt>,
pub target_size: Option<TargetSizeStr>,
pub target_size_ratio: Option<f64>,
pub additional_properties: HashMap<String, Value>,
}Fields
add_storages: Option<bool>Configure VM and CT storage using the new pool.
application: Option<Application>The application of the pool.
crush_rule: Option<String>The rule to use for mapping object placement in the cluster.
erasure_coding: Option<String>Create an erasure coded pool for RBD with an accompaning replicated pool for metadata storage. With EC, the common ceph options ‘size’, ‘min_size’ and ‘crush_rule’ parameters will be applied to the metadata pool.
min_size: Option<MinSizeInt>Minimum number of replicas per object
name: NameStrThe name of the pool. It must be unique.
pg_autoscale_mode: Option<PgAutoscaleMode>The automatic PG scaling mode of the pool.
pg_num: Option<PgNumInt>Number of placement groups.
pg_num_min: Option<PgNumMinInt>Minimal number of placement groups.
size: Option<SizeInt>Number of replicas per object
target_size: Option<TargetSizeStr>The estimated target size of the pool for the PG autoscaler.
target_size_ratio: Option<f64>The estimated target ratio of the pool for the PG autoscaler.
additional_properties: HashMap<String, Value>Implementations