pub struct GetOutput {
pub allowed_nodes: Vec<String>,
pub dependent_ha_resources: Vec<String>,
pub not_allowed_nodes: Option<NotAllowedNodesGetOutputNotAllowedNodes>,
pub running: bool,
pub additional_properties: HashMap<String, Value>,
}Fields
allowed_nodes: Vec<String>List of nodes allowed for migration.
dependent_ha_resources: Vec<String>HA resources, which will be migrated to the same target node as the VM, because these are in positive affinity with the VM.
not_allowed_nodes: Option<NotAllowedNodesGetOutputNotAllowedNodes>List of not allowed nodes with additional information.
running: boolDetermines if the container is running.
additional_properties: HashMap<String, Value>Implementations