pub struct MoveVolumeClient<T> { /* private fields */ }Implementations
Sourceimpl<T> MoveVolumeClient<T>where
T: Client,
impl<T> MoveVolumeClient<T>where
T: Client,
Sourceimpl<T> MoveVolumeClient<T>where
T: Client,
impl<T> MoveVolumeClient<T>where
T: Client,
Sourcepub async fn post(&self, params: PostParams) -> Result<String, T::Error>
pub async fn post(&self, params: PostParams) -> Result<String, T::Error>
Move a rootfs-/mp-volume to a different storage or to a different container.
Permission check: perm(“/vms/{vmid}”, [“VM.Config.Disk”]) You need ‘VM.Config.Disk’ permissions on /vms/{vmid}, and ‘Datastore.AllocateSpace’ permissions on the storage. To move a volume to another container, you need the permissions on the target container as well.