GetOutputItems

Struct GetOutputItems 

pub struct GetOutputItems {
Show 49 fields pub active: Option<bool>, pub address: Option<Ipv4Addr>, pub address6: Option<Ipv6Addr>, pub autostart: Option<bool>, pub bond_primary: Option<String>, pub bond_mode: Option<BondMode>, pub bond_xmit_hash_policy: Option<BondXmitHashPolicy>, pub bridge_access: Option<i64>, pub bridge_arp_nd_suppress: Option<bool>, pub bridge_learning: Option<bool>, pub bridge_multicast_flood: Option<bool>, pub bridge_unicast_flood: Option<bool>, pub bridge_ports: Option<String>, pub bridge_vids: Option<String>, pub bridge_vlan_aware: Option<bool>, pub cidr: Option<String>, pub cidr6: Option<String>, pub comments: Option<String>, pub comments6: Option<String>, pub exists: Option<bool>, pub families: Vec<Families>, pub gateway: Option<Ipv4Addr>, pub gateway6: Option<Ipv6Addr>, pub iface: IfaceStr, pub link_type: Option<String>, pub method: Option<Method>, pub method6: Option<Method6>, pub mtu: Option<MtuInt>, pub netmask: Option<String>, pub netmask6: Option<Netmask6Int>, pub options: Vec<String>, pub options6: Vec<String>, pub ovs_bonds: Option<String>, pub ovs_bridge: Option<String>, pub ovs_options: Option<OvsOptionsStr>, pub ovs_ports: Option<String>, pub ovs_tag: Option<OvsTagInt>, pub priority: Option<i64>, pub slaves: Option<String>, pub ty: Type2, pub uplink_id: Option<String>, pub vlan_id: Option<VlanIdInt>, pub vlan_protocol: Option<VlanProtocol>, pub vlan_raw_device: Option<String>, pub vxlan_id: Option<i64>, pub vxlan_local_tunnelip: Option<String>, pub vxlan_physdev: Option<String>, pub vxlan_svcnodeip: Option<String>, pub additional_properties: HashMap<String, Value>,
}

Fields

active: Option<bool>

Set to true if the interface is active.

address: Option<Ipv4Addr>

IP address.

address6: Option<Ipv6Addr>

IP address.

autostart: Option<bool>

Automatically start interface on boot.

bond_primary: Option<String>

Specify the primary interface for active-backup bond.

bond_mode: Option<BondMode>

Bonding mode.

bond_xmit_hash_policy: Option<BondXmitHashPolicy>

Selects the transmit hash policy to use for slave selection in balance-xor and 802.3ad modes.

bridge_access: Option<i64>

The bridge port access VLAN.

bridge_arp_nd_suppress: Option<bool>

Bridge port ARP/ND suppress flag.

bridge_learning: Option<bool>

Bridge port learning flag.

bridge_multicast_flood: Option<bool>

Bridge port multicast flood flag.

bridge_unicast_flood: Option<bool>

Bridge port unicast flood flag.

bridge_ports: Option<String>

Specify the interfaces you want to add to your bridge.

bridge_vids: Option<String>

Specify the allowed VLANs. For example: ‘2 4 100-200’. Only used if the bridge is VLAN aware.

bridge_vlan_aware: Option<bool>

Enable bridge vlan support.

cidr: Option<String>

IPv4 CIDR.

cidr6: Option<String>

IPv6 CIDR.

comments: Option<String>

Comments

comments6: Option<String>

Comments

exists: Option<bool>

Set to true if the interface physically exists.

families: Vec<Families>

The network families.

gateway: Option<Ipv4Addr>

Default gateway address.

gateway6: Option<Ipv6Addr>

Default ipv6 gateway address.

iface: IfaceStr

Network interface name.

link_type: Option<String>

The link type.

method: Option<Method>

The network configuration method for IPv4.

method6: Option<Method6>

The network configuration method for IPv6.

mtu: Option<MtuInt>

MTU.

netmask: Option<String>

Network mask.

netmask6: Option<Netmask6Int>

Network mask.

options: Vec<String>

A list of additional interface options for IPv4.

options6: Vec<String>

A list of additional interface options for IPv6.

ovs_bonds: Option<String>

Specify the interfaces used by the bonding device.

ovs_bridge: Option<String>

The OVS bridge associated with a OVS port. This is required when you create an OVS port.

ovs_options: Option<OvsOptionsStr>

OVS interface options.

ovs_ports: Option<String>

Specify the interfaces you want to add to your bridge.

ovs_tag: Option<OvsTagInt>

Specify a VLan tag (used by OVSPort, OVSIntPort, OVSBond)

priority: Option<i64>

The order of the interface.

slaves: Option<String>

Specify the interfaces used by the bonding device.

ty: Type2

Network interface type

uplink_id: Option<String>

The uplink ID.

vlan_id: Option<VlanIdInt>

vlan-id for a custom named vlan interface (ifupdown2 only).

vlan_protocol: Option<VlanProtocol>

The VLAN protocol.

vlan_raw_device: Option<String>

Specify the raw interface for the vlan interface.

vxlan_id: Option<i64>

The VXLAN ID.

vxlan_local_tunnelip: Option<String>

The VXLAN local tunnel IP.

vxlan_physdev: Option<String>

The physical device for the VXLAN tunnel.

vxlan_svcnodeip: Option<String>

The VXLAN SVC node IP.

additional_properties: HashMap<String, Value>

Implementations

Source

impl GetOutputItems

pub fn new(iface: IfaceStr, ty: Type2) -> Self