pub struct PostParams {Show 29 fields
pub address: Option<Ipv4Addr>,
pub address6: Option<Ipv6Addr>,
pub autostart: Option<bool>,
pub bond_primary: Option<String>,
pub bond_mode: Option<BondMode>,
pub bond_xmit_hash_policy: Option<BondXmitHashPolicy>,
pub bridge_ports: Option<String>,
pub bridge_vids: Option<String>,
pub bridge_vlan_aware: Option<bool>,
pub cidr: Option<String>,
pub cidr6: Option<String>,
pub comments: Option<String>,
pub comments6: Option<String>,
pub gateway: Option<Ipv4Addr>,
pub gateway6: Option<Ipv6Addr>,
pub iface: IfaceStr,
pub mtu: Option<MtuInt>,
pub netmask: Option<String>,
pub netmask6: Option<Netmask6Int>,
pub ovs_bonds: Option<String>,
pub ovs_bridge: Option<String>,
pub ovs_options: Option<OvsOptionsStr>,
pub ovs_ports: Option<String>,
pub ovs_tag: Option<OvsTagInt>,
pub slaves: Option<String>,
pub ty: Type3,
pub vlan_id: Option<VlanIdInt>,
pub vlan_raw_device: Option<String>,
pub additional_properties: HashMap<String, Value>,
}Fields
address: Option<Ipv4Addr>IP address.
address6: Option<Ipv6Addr>IP address.
autostart: Option<bool>Automatically start interface on boot.
bond_primary: Option<String>Specify the primary interface for active-backup bond.
bond_mode: Option<BondMode>Bonding mode.
bond_xmit_hash_policy: Option<BondXmitHashPolicy>Selects the transmit hash policy to use for slave selection in balance-xor and 802.3ad modes.
bridge_ports: Option<String>Specify the interfaces you want to add to your bridge.
bridge_vids: Option<String>Specify the allowed VLANs. For example: ‘2 4 100-200’. Only used if the bridge is VLAN aware.
bridge_vlan_aware: Option<bool>Enable bridge vlan support.
cidr: Option<String>IPv4 CIDR.
cidr6: Option<String>IPv6 CIDR.
comments: Option<String>Comments
comments6: Option<String>Comments
gateway: Option<Ipv4Addr>Default gateway address.
gateway6: Option<Ipv6Addr>Default ipv6 gateway address.
iface: IfaceStrNetwork interface name.
mtu: Option<MtuInt>MTU.
netmask: Option<String>Network mask.
netmask6: Option<Netmask6Int>Network mask.
ovs_bonds: Option<String>Specify the interfaces used by the bonding device.
ovs_bridge: Option<String>The OVS bridge associated with a OVS port. This is required when you create an OVS port.
ovs_options: Option<OvsOptionsStr>OVS interface options.
ovs_ports: Option<String>Specify the interfaces you want to add to your bridge.
ovs_tag: Option<OvsTagInt>Specify a VLan tag (used by OVSPort, OVSIntPort, OVSBond)
slaves: Option<String>Specify the interfaces used by the bonding device.
ty: Type3Network interface type
vlan_id: Option<VlanIdInt>vlan-id for a custom named vlan interface (ifupdown2 only).
vlan_raw_device: Option<String>Specify the raw interface for the vlan interface.
additional_properties: HashMap<String, Value>Implementations