pub struct GetOutputItems {Show 29 fields
pub cpu: Option<f64>,
pub cpus: Option<f64>,
pub diskread: Option<i64>,
pub diskwrite: Option<i64>,
pub lock: Option<String>,
pub maxdisk: Option<i64>,
pub maxmem: Option<i64>,
pub mem: Option<i64>,
pub memhost: Option<i64>,
pub name: Option<String>,
pub netin: Option<i64>,
pub netout: Option<i64>,
pub pid: Option<i64>,
pub pressurecpufull: Option<f64>,
pub pressurecpusome: Option<f64>,
pub pressureiofull: Option<f64>,
pub pressureiosome: Option<f64>,
pub pressurememoryfull: Option<f64>,
pub pressurememorysome: Option<f64>,
pub qmpstatus: Option<String>,
pub running_machine: Option<String>,
pub running_qemu: Option<String>,
pub serial: Option<bool>,
pub status: Status,
pub tags: Option<String>,
pub template: Option<bool>,
pub uptime: Option<i64>,
pub vmid: VmidInt,
pub additional_properties: HashMap<String, Value>,
}Fields
cpu: Option<f64>Current CPU usage.
cpus: Option<f64>Maximum usable CPUs.
diskread: Option<i64>The amount of bytes the guest read from it’s block devices since the guest was started. (Note: This info is not available for all storage types.)
diskwrite: Option<i64>The amount of bytes the guest wrote from it’s block devices since the guest was started. (Note: This info is not available for all storage types.)
lock: Option<String>The current config lock, if any.
maxdisk: Option<i64>Root disk size in bytes.
maxmem: Option<i64>Maximum memory in bytes.
mem: Option<i64>Currently used memory in bytes.
memhost: Option<i64>Current memory usage on the host.
name: Option<String>VM (host)name.
netin: Option<i64>The amount of traffic in bytes that was sent to the guest over the network since it was started.
netout: Option<i64>The amount of traffic in bytes that was sent from the guest over the network since it was started.
pid: Option<i64>PID of the QEMU process, if the VM is running.
pressurecpufull: Option<f64>CPU Full pressure stall average over the last 10 seconds.
pressurecpusome: Option<f64>CPU Some pressure stall average over the last 10 seconds.
pressureiofull: Option<f64>IO Full pressure stall average over the last 10 seconds.
pressureiosome: Option<f64>IO Some pressure stall average over the last 10 seconds.
pressurememoryfull: Option<f64>Memory Full pressure stall average over the last 10 seconds.
pressurememorysome: Option<f64>Memory Some pressure stall average over the last 10 seconds.
qmpstatus: Option<String>VM run state from the ‘query-status’ QMP monitor command.
running_machine: Option<String>The currently running machine type (if running).
running_qemu: Option<String>The QEMU version the VM is currently using (if running).
serial: Option<bool>Guest has serial device configured.
status: StatusQEMU process status.
The current configured tags, if any
template: Option<bool>Determines if the guest is a template.
uptime: Option<i64>Uptime in seconds.
vmid: VmidIntThe (unique) ID of the VM.
additional_properties: HashMap<String, Value>Implementations