PutParams

Struct PutParams 

pub struct PutParams {
Show 51 fields pub blocksize: Option<String>, pub bwlimit: Option<String>, pub comstar_hg: Option<String>, pub comstar_tg: Option<String>, pub content: Option<String>, pub content_dirs: Option<String>, pub create_base_path: Option<bool>, pub create_subdirs: Option<bool>, pub data_pool: Option<String>, pub delete: Option<DeleteStr>, pub digest: Option<DigestStr>, pub disable: Option<bool>, pub domain: Option<DomainStr>, pub encryption_key: Option<String>, pub fingerprint: Option<FingerprintStr>, pub format: Option<Format>, pub fs_name: Option<String>, pub fuse: Option<bool>, pub is_mountpoint: Option<String>, pub keyring: Option<String>, pub krbd: Option<bool>, pub lio_tpg: Option<String>, pub master_pubkey: Option<String>, pub max_protected_backups: Option<MaxProtectedBackupsInt>, pub mkdir: Option<bool>, pub monhost: Option<String>, pub mountpoint: Option<String>, pub namespace: Option<String>, pub nocow: Option<bool>, pub nodes: Option<String>, pub nowritecache: Option<bool>, pub options: Option<String>, pub password: Option<PasswordStr>, pub pool: Option<String>, pub port: Option<PortInt>, pub preallocation: Option<Preallocation>, pub prune_backups: Option<String>, pub saferemove: Option<bool>, pub saferemove_stepsize: Option<SaferemoveStepsizeInt>, pub saferemove_throughput: Option<String>, pub server: Option<String>, pub shared: Option<bool>, pub skip_cert_verification: Option<bool>, pub smbversion: Option<Smbversion>, pub snapshot_as_volume_chain: Option<bool>, pub sparse: Option<bool>, pub subdir: Option<String>, pub tagged_only: Option<bool>, pub username: Option<String>, pub zfs_base_path: Option<String>, pub additional_properties: HashMap<String, Value>,
}

Fields

blocksize: Option<String>

block size

bwlimit: Option<String>

Set I/O bandwidth limit for various operations (in KiB/s).

comstar_hg: Option<String>

host group for comstar views

comstar_tg: Option<String>

target group for comstar views

content: Option<String>

Allowed content types.

NOTE: the value ‘rootdir’ is used for Containers, and value ‘images’ for VMs.

content_dirs: Option<String>

Overrides for default content type directories.

create_base_path: Option<bool>

Create the base directory if it doesn’t exist.

create_subdirs: Option<bool>

Populate the directory with the default structure.

data_pool: Option<String>

Data Pool (for erasure coding only)

delete: Option<DeleteStr>

A list of settings you want to delete.

digest: Option<DigestStr>

Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.

disable: Option<bool>

Flag to disable the storage.

domain: Option<DomainStr>

CIFS domain.

encryption_key: Option<String>

Encryption key. Use ‘autogen’ to generate one automatically without passphrase.

fingerprint: Option<FingerprintStr>

Certificate SHA 256 fingerprint.

format: Option<Format>

Default image format.

fs_name: Option<String>

The Ceph filesystem name.

fuse: Option<bool>

Mount CephFS through FUSE.

is_mountpoint: Option<String>

Assume the given path is an externally managed mountpoint and consider the storage offline if it is not mounted. Using a boolean (yes/no) value serves as a shortcut to using the target path in this field.

keyring: Option<String>

Client keyring contents (for external clusters).

krbd: Option<bool>

Always access rbd through krbd kernel module.

lio_tpg: Option<String>

target portal group for Linux LIO targets

master_pubkey: Option<String>

Base64-encoded, PEM-formatted public RSA key. Used to encrypt a copy of the encryption-key which will be added to each encrypted backup.

max_protected_backups: Option<MaxProtectedBackupsInt>

Maximal number of protected backups per guest. Use ‘-1’ for unlimited.

mkdir: Option<bool>

Create the directory if it doesn’t exist and populate it with default sub-dirs. NOTE: Deprecated, use the ‘create-base-path’ and ‘create-subdirs’ options instead.

monhost: Option<String>

IP addresses of monitors (for external clusters).

mountpoint: Option<String>

mount point

namespace: Option<String>

Namespace.

nocow: Option<bool>

Set the NOCOW flag on files. Disables data checksumming and causes data errors to be unrecoverable from while allowing direct I/O. Only use this if data does not need to be any more safe than on a single ext4 formatted disk with no underlying raid system.

nodes: Option<String>

List of nodes for which the storage configuration applies.

nowritecache: Option<bool>

disable write caching on the target

options: Option<String>

NFS/CIFS mount options (see ‘man nfs’ or ‘man mount.cifs’)

password: Option<PasswordStr>

Password for accessing the share/datastore.

pool: Option<String>

Pool.

port: Option<PortInt>

Use this port to connect to the storage instead of the default one (for example, with PBS or ESXi). For NFS and CIFS, use the ‘options’ option to configure the port via the mount options.

preallocation: Option<Preallocation>

Preallocation mode for raw and qcow2 images. Using ‘metadata’ on raw images results in preallocation=off.

prune_backups: Option<String>

The retention options with shorter intervals are processed first with –keep-last being the very first one. Each option covers a specific period of time. We say that backups within this period are covered by this option. The next option does not take care of already covered backups and only considers older backups.

saferemove: Option<bool>

Zero-out data when removing LVs.

saferemove_stepsize: Option<SaferemoveStepsizeInt>

Wipe step size in MiB. It will be capped to the maximum supported by the storage.

saferemove_throughput: Option<String>

Wipe throughput (cstream -t parameter value).

server: Option<String>

Server IP or DNS name.

shared: Option<bool>

Indicate that this is a single storage with the same contents on all nodes (or all listed in the ‘nodes’ option). It will not make the contents of a local storage automatically accessible to other nodes, it just marks an already shared storage as such!

skip_cert_verification: Option<bool>

Disable TLS certificate verification, only enable on fully trusted networks!

smbversion: Option<Smbversion>

SMB protocol version. ‘default’ if not set, negotiates the highest SMB2+ version supported by both the client and server.

snapshot_as_volume_chain: Option<bool>

Enable support for creating storage-vendor agnostic snapshot through volume backing-chains.

sparse: Option<bool>

use sparse volumes

subdir: Option<String>

Subdir to mount.

tagged_only: Option<bool>

Only use logical volumes tagged with ‘pve-vm-ID’.

username: Option<String>

RBD Id.

zfs_base_path: Option<String>

Base path where to look for the created ZFS block devices. Set automatically during creation if not specified. Usually ‘/dev/zvol’.

additional_properties: HashMap<String, Value>