Module multi

Module multi 

This module contains structures required to handle multi-fields, i.e. link[n]. In these fields, the name of the field is dependent on the number, so it requires some extra handling to get right.

Additional data also needs extra handling in this case, which this module also provides.

Traits

NumberedItems
Test

Functions

deserialize_additional_data
deserialize_multi
deserialize_multi_btree
serialize_multi
serialize_multi_btree