Modules
Structs
- Backup
Client - Comment
Str - GetOutput
Items - IdStr
- Ionice
Int - Lockwait
Int - Notes
Template Str - Post
Params - Schedule
Str - Starttime
Str - Stopwait
Int - ZstdInt
Enums
- Compress
- Compress dump file.
- Mailnotification
- Deprecated: use notification targets/matchers instead. Specify when to send a notification mail
- Mode
- Backup mode.
- Notification
Mode - Determine which notification system to use. If set to ‘legacy-sendmail’, vzdump will consider the mailto/mailnotification parameters and send emails to the specified address(es) via the ‘sendmail’ command. If set to ‘notification-system’, a notification will be sent via PVE’s notification system, and the mailto and mailnotification will be ignored. If set to ‘auto’ (default setting), an email will be sent if mailto is set, and the notification system will be used if not.
- PbsChange
Detection Mode - PBS mode used to detect file changes and switch encoding format for container backups.