pub struct GetOutput {Show 24 fields
pub application: Option<Application>,
pub autoscale_status: Option<AutoscaleStatusGetOutputAutoscaleStatus>,
pub crush_rule: Option<String>,
pub fast_read: bool,
pub hashpspool: bool,
pub id: i64,
pub min_size: Option<MinSizeInt>,
pub name: NameStr,
pub nodeep_scrub: bool,
pub nodelete: bool,
pub nopgchange: bool,
pub noscrub: bool,
pub nosizechange: bool,
pub pg_autoscale_mode: Option<PgAutoscaleMode>,
pub pg_num: Option<PgNumInt>,
pub pg_num_min: Option<PgNumMinInt>,
pub pgp_num: i64,
pub size: Option<SizeInt>,
pub statistics: Option<StatisticsGetOutputStatistics>,
pub target_size: Option<TargetSizeStr>,
pub target_size_ratio: Option<f64>,
pub use_gmt_hitset: bool,
pub write_fadvise_dontneed: bool,
pub additional_properties: HashMap<String, Value>,
}Fields
application: Option<Application>The application of the pool.
autoscale_status: Option<AutoscaleStatusGetOutputAutoscaleStatus>crush_rule: Option<String>The rule to use for mapping object placement in the cluster.
fast_read: boolhashpspool: boolid: i64min_size: Option<MinSizeInt>Minimum number of replicas per object
name: NameStrThe name of the pool. It must be unique.
nodeep_scrub: boolnodelete: boolnopgchange: boolnoscrub: boolnosizechange: boolpg_autoscale_mode: Option<PgAutoscaleMode>The automatic PG scaling mode of the pool.
pg_num: Option<PgNumInt>Number of placement groups.
pg_num_min: Option<PgNumMinInt>Minimal number of placement groups.
pgp_num: i64size: Option<SizeInt>Number of replicas per object
statistics: Option<StatisticsGetOutputStatistics>target_size: Option<TargetSizeStr>The estimated target size of the pool for the PG autoscaler.
target_size_ratio: Option<f64>The estimated target ratio of the pool for the PG autoscaler.
use_gmt_hitset: boolwrite_fadvise_dontneed: booladditional_properties: HashMap<String, Value>Implementations